@@ -34,6 +34,8 @@
 
 #ifdef HAVE_OPUS
 
+//#define DEBUG_OPUS_WRITE 1
+
 #include "OpusWriteStream.h"
 
 #include <opus/opusenc.h>
@@ -62,17 +64,20 @@ opuswritebuilder(
 class OpusWriteStream::D
 {
 public:
-    D() : encoder(0) { }
+    D() : encoder(0), begun(false) { }
 
     OggOpusComments *comments;
     OggOpusEnc *encoder;
+    bool begun;
 };
 
 OpusWriteStream::OpusWriteStream(Target target) :
     AudioWriteStream(target),
     m_d(new D)
 {
-//    cerr << "OpusWriteStream: file is " << getPath() << ", channel count is " << getChannelCount() << ", sample rate " << getSampleRate() << endl;
+#ifdef DEBUG_OPUS_WRITE
+    std::cerr << "OpusWriteStream::OpusWriteStream: file is " << getPath() << ", channel count is " << getChannelCount() << ", sample rate " << getSampleRate() << std::endl;
+#endif
 
     //!!! +windows file encoding?
 
@@ -85,11 +90,11 @@ OpusWriteStream::OpusWriteStream(Target target) :
                                            &err);
 
     if (err || !m_d->encoder) {
-        ostringstream os;    
+        std::ostringstream os;    
         os << "OpusWriteStream: Unable to open file for writing (error code "
            << err << ")";
         m_error = os.str();
-        cerr << m_error << endl;
+        std::cerr << m_error << std::endl;
         m_d->encoder = 0;
         throw FailedToWriteFile(getPath());
     }    
@@ -98,12 +103,24 @@ OpusWriteStream::OpusWriteStream(Target target) :
 OpusWriteStream::~OpusWriteStream()
 {
     if (m_d->encoder) {
-//        cerr << "OpusWriteStream::~OpusWriteStream: closing" << endl;
-        int err = ope_encoder_drain(m_d->encoder);
-        if (err) {
-            cerr << "WARNING: ope_encoder_drain failed (error code "
-                 << err << ")" << endl;
+#ifdef DEBUG_OPUS_WRITE
+        std::cerr << "OpusWriteStream::~OpusWriteStream: closing" << std::endl;
+#endif
+        if (m_d->begun) {
+            int err = ope_encoder_drain(m_d->encoder);
+            if (err) {
+                std::cerr << "WARNING: ope_encoder_drain failed (error code "
+                          << err << ")" << std::endl;
+            }
+        } else {
+            // ope_encoder_drain can crash (!) if called without any
+            // data having been previously written - see
+            // https://github.com/xiph/libopusenc/issues/24
+#ifdef DEBUG_OPUS_WRITE
+            std::cerr << "OpusWriteStream::~OpusWriteStream: not draining (nothing has been written)" << std::endl;
+#endif
         }
+            
         ope_encoder_destroy(m_d->encoder);
         ope_comments_destroy(m_d->comments);
     }
@@ -112,18 +129,30 @@ OpusWriteStream::~OpusWriteStream()
 void
 OpusWriteStream::putInterleavedFrames(size_t count, const float *frames)
 {
-    if (count == 0 || !m_d->encoder) return;
+    if (count == 0 || !m_d->encoder) {
+#ifdef DEBUG_OPUS_WRITE
+        std::cerr << "OpusWriteStream::putInterleavedFrames: No encoder!"
+                  << std::endl;
+#endif
+        return;
+    }
 
     int err = ope_encoder_write_float(m_d->encoder, frames, count);
 
     if (err) {
-        ostringstream os;    
+        std::ostringstream os;    
         os << "OpusWriteStream: Failed to write frames to encoder (error code "
            << err << ")";
         m_error = os.str();
-        cerr << m_error << endl;
+        std::cerr << m_error << std::endl;
         throw FileOperationFailed(getPath(), "encode");
     }
+
+    m_d->begun = true;
+    
+#ifdef DEBUG_OPUS_WRITE
+    std::cerr << "OpusWriteStream::putInterleavedFrames: wrote " << count << " frames" << std::endl;
+#endif
 }
 
 }
