@@ -22,6 +22,7 @@
 #include "ColourMapper.h"
 #include "LayerGeometryProvider.h"
 #include "PaintAssistant.h"
+#include "Colour3DPlotExporter.h"
 
 #include "data/model/Dense3DModelPeakCache.h"
 
@@ -70,6 +71,14 @@ Colour3DPlotLayer::Colour3DPlotLayer() :
 Colour3DPlotLayer::~Colour3DPlotLayer()
 {
     invalidateRenderers();
+    
+    for (auto exporterId: m_exporters) {
+        if (auto exporter =
+            ModelById::getAs<Colour3DPlotExporter>(exporterId)) {
+            exporter->discardSources();
+        }
+        ModelById::release(exporterId);
+    }
 }
 
 const ZoomConstraint *
@@ -207,6 +216,31 @@ Colour3DPlotLayer::invalidateMagnitudes()
     m_viewMags.clear();
 }
 
+ModelId
+Colour3DPlotLayer::getExportModel(LayerGeometryProvider *v) const
+{
+    // Creating Colour3DPlotExporters is cheap, so we create one on
+    // every call - calls probably being infrequent - to avoid having
+    // to worry about view lifecycles.
+
+    auto model = ModelById::getAs<DenseThreeDimensionalModel>(m_model);
+    if (!model) return {};
+    
+    Colour3DPlotExporter::Sources sources;
+    sources.verticalBinLayer = this;
+    sources.source = m_model;
+    sources.provider = v;
+        
+    Colour3DPlotExporter::Parameters params;
+    // No thresholding for Colour3DPlot layers, so no need for gain or
+    // normalisaion values either
+    
+    ModelId exporter = ModelById::add
+        (std::make_shared<Colour3DPlotExporter>(sources, params));
+    m_exporters.push_back(exporter);
+    return exporter;
+}
+
 ModelId
 Colour3DPlotLayer::getPeakCache() const
 {
