@@ -192,14 +192,29 @@ AlignmentView::paintEvent(QPaintEvent *)
     int w = width();
     int h = height();
 
-    if (m_leftmostAbove > 0) {
-    
+    if (m_leftmostAbove >= 0) {
+
+#ifdef DEBUG_ALIGNMENT_VIEW
+        SVCERR << "AlignmentView: m_leftmostAbove = " << m_leftmostAbove
+               << ", we have a relationship with the pane above us: showing "
+               << "mappings in relation to that" << endl;
+#endif
+
         for (const auto &km: m_fromAboveMap) {
 
             sv_frame_t af = km.first;
             sv_frame_t bf = km.second;
             
-            if (af < m_leftmostAbove || af > m_rightmostAbove) {
+            if (af < m_leftmostAbove) {
+#ifdef DEBUG_ALIGNMENT_VIEW
+                SVCERR << "AlignmentView: af " << af << " < m_leftmostAbove " << m_leftmostAbove << endl;
+#endif
+                continue;
+            }
+            if (af > m_rightmostAbove) {
+#ifdef DEBUG_ALIGNMENT_VIEW
+                SVCERR << "AlignmentView: af " << af << " > m_rightmostAbove " << m_rightmostAbove << endl;
+#endif
                 continue;
             }
 
@@ -213,7 +228,13 @@ AlignmentView::paintEvent(QPaintEvent *)
     } else if (m_reference != nullptr) {
         // the below has nothing in common with the above: show things
         // in common with the reference instead
-    
+
+#ifdef DEBUG_ALIGNMENT_VIEW
+        SVCERR << "AlignmentView: m_leftmostAbove = " << m_leftmostAbove
+               << ", we have no relationship with the pane above us: showing "
+               << "mappings in relation to the reference instead" << endl;
+#endif
+
         for (const auto &km: m_fromReferenceMap) {
             
             sv_frame_t af = km.first;
@@ -293,21 +314,21 @@ AlignmentView::buildMaps()
     m_leftmostAbove = -1;
     m_rightmostAbove = -1;
 
-    sv_frame_t prevRf = -1;
+    sv_frame_t prevAf = -1;
     sv_frame_t prevBf = -1;
     
-    foreach (sv_frame_t f, keyFrames) {
+    foreach (sv_frame_t af, keyFrames) {
 
-        sv_frame_t rf = m_above->alignToReference(f);
+        sv_frame_t rf = m_above->alignToReference(af);
         sv_frame_t bf = m_below->alignFromReference(rf);
 
         if (prevBf > 0 && bf > prevBf) {
-            if (m_leftmostAbove < 0 && prevBf > 0 && bf > prevBf) {
-                m_leftmostAbove = prevRf;
+            if (m_leftmostAbove < 0) {
+                m_leftmostAbove = prevAf;
             }
-            m_rightmostAbove = rf;
+            m_rightmostAbove = af;
         }
-        prevRf = rf;
+        prevAf = af;
         prevBf = bf;
         
         bool mappedSomething = false;
@@ -315,13 +336,13 @@ AlignmentView::buildMaps()
         if (resolution > 1) {
             if (keyFramesBelow.find(bf) == keyFramesBelow.end()) {
 
-                sv_frame_t f1 = f + resolution;
-                sv_frame_t rf1 = m_above->alignToReference(f1);
+                sv_frame_t af1 = af + resolution;
+                sv_frame_t rf1 = m_above->alignToReference(af1);
                 sv_frame_t bf1 = m_below->alignFromReference(rf1);
 
                 for (sv_frame_t probe = bf + 1; probe <= bf1; ++probe) {
                     if (keyFramesBelow.find(probe) != keyFramesBelow.end()) {
-                        m_fromAboveMap.insert({ f, probe });
+                        m_fromAboveMap.insert({ af, probe });
                         mappedSomething = true;
                     }
                 }
@@ -329,7 +350,7 @@ AlignmentView::buildMaps()
         }
 
         if (!mappedSomething) {
-            m_fromAboveMap.insert({ f, bf });
+            m_fromAboveMap.insert({ af, bf });
         }
     }
 
