@@ -568,6 +568,11 @@ protected:
 
     QString             m_lastError;
 
+#ifdef Q_OS_MAC
+    mutable bool        m_useRetinaResolution;
+    mutable bool        m_useRetinaResolutionChecked;
+#endif
+    
     // caches for use in getScrollableBackLayers, getNonScrollableFrontLayers
     mutable LayerList m_lastScrollableBackLayers;
     mutable LayerList m_lastNonScrollableBackLayers;
