@@ -29,6 +29,7 @@
 #include "LevelPanWidget.h"
 #include "LevelPanToolButton.h"
 #include "WidgetScale.h"
+#include "MenuTitle.h"
 
 #include "NotifyingCheckBox.h"
 #include "NotifyingComboBox.h"
@@ -48,6 +49,7 @@
 #include <QColorDialog>
 #include <QInputDialog>
 #include <QDir>
+#include <QMenu>
 
 #include <cassert>
 #include <iostream>
@@ -58,7 +60,9 @@
 PropertyBox::PropertyBox(PropertyContainer *container) :
     m_container(container),
     m_showButton(nullptr),
-    m_playButton(nullptr)
+    m_playButton(nullptr),
+    m_lastContextMenu(nullptr),
+    m_contextMenuOn(nullptr)
 {
 #ifdef DEBUG_PROPERTY_BOX
     SVDEBUG << "PropertyBox[" << this << "(\"" <<
@@ -118,6 +122,7 @@ PropertyBox::~PropertyBox()
 #ifdef DEBUG_PROPERTY_BOX
     SVDEBUG << "PropertyBox[" << this << "]::~PropertyBox" << endl;
 #endif
+    delete m_lastContextMenu;
 }
 
 void
@@ -264,6 +269,9 @@ PropertyBox::updatePropertyEditor(PropertyContainer::PropertyName name,
     }
     
     if (!have) {
+#ifdef DEBUG_PROPERTY_BOX 
+        SVDEBUG << "PropertyBox: this property is new to us" << endl;
+#endif
         if (m_groupLayouts.find(groupName) == m_groupLayouts.end()) {
             QWidget *labelWidget = new QLabel(groupLabel, m_mainWidget);
             m_layout->addWidget(labelWidget, row, 0);
@@ -301,7 +309,11 @@ PropertyBox::updatePropertyEditor(PropertyContainer::PropertyName name,
     {
         QAbstractButton *button;
 
-        if (!(button = qobject_cast<QAbstractButton *>(existing))) {
+        if ((button = qobject_cast<QAbstractButton *>(existing))) {
+#ifdef DEBUG_PROPERTY_BOX 
+            SVDEBUG << "PropertyBox: we already have a checkbox" << endl;
+#endif
+        } else {
 #ifdef DEBUG_PROPERTY_BOX 
             SVDEBUG << "PropertyBox: creating new checkbox" << endl;
 #endif
@@ -328,6 +340,10 @@ PropertyBox::updatePropertyEditor(PropertyContainer::PropertyName name,
                     this, SLOT(mouseLeftWidget()));
             button->setToolTip(propertyLabel);
 
+            button->setContextMenuPolicy(Qt::CustomContextMenu);
+            connect(button, SIGNAL(customContextMenuRequested(const QPoint &)),
+                    this, SLOT(contextMenuRequested(const QPoint &)));
+
             if (existing) {
                 groupLayout->replaceWidget(existing, button);
                 delete existing;
@@ -351,7 +367,13 @@ PropertyBox::updatePropertyEditor(PropertyContainer::PropertyName name,
         AudioDial *dial;
 
         if ((dial = qobject_cast<AudioDial *>(existing))) {
+#ifdef DEBUG_PROPERTY_BOX 
+            SVDEBUG << "PropertyBox: we already have a dial" << endl;
+#endif
             if (rangeChanged) {
+#ifdef DEBUG_PROPERTY_BOX 
+                SVDEBUG << "PropertyBox: range changed, respecifying" << endl;
+#endif
                 dial->blockSignals(true);
                 dial->setMinimum(min);
                 dial->setMaximum(max);
@@ -405,8 +427,11 @@ PropertyBox::updatePropertyEditor(PropertyContainer::PropertyName name,
     {
         ColourComboBox *cb;
         
-        if (!(cb = qobject_cast<ColourComboBox *>(existing))) {
-
+        if ((cb = qobject_cast<ColourComboBox *>(existing))) {
+#ifdef DEBUG_PROPERTY_BOX 
+            SVDEBUG << "PropertyBox: we already have a colour combobox" << endl;
+#endif
+        } else {
 #ifdef DEBUG_PROPERTY_BOX 
             SVDEBUG << "PropertyBox: creating new colour combobox" << endl;
 #endif
@@ -422,6 +447,10 @@ PropertyBox::updatePropertyEditor(PropertyContainer::PropertyName name,
 
             cb->setToolTip(propertyLabel);
 
+            cb->setContextMenuPolicy(Qt::CustomContextMenu);
+            connect(cb, SIGNAL(customContextMenuRequested(const QPoint &)),
+                    this, SLOT(contextMenuRequested(const QPoint &)));
+
             if (existing) {
                 groupLayout->replaceWidget(existing, cb);
                 delete existing;
@@ -445,7 +474,11 @@ PropertyBox::updatePropertyEditor(PropertyContainer::PropertyName name,
     {
         ColourMapComboBox *cb;
 
-        if (!(cb = qobject_cast<ColourMapComboBox *>(existing))) {
+        if ((cb = qobject_cast<ColourMapComboBox *>(existing))) {
+#ifdef DEBUG_PROPERTY_BOX 
+            SVDEBUG << "PropertyBox: we already have a colourmap combobox" << endl;
+#endif
+        } else {
 #ifdef DEBUG_PROPERTY_BOX 
             SVDEBUG << "PropertyBox: creating new colourmap combobox" << endl;
 #endif
@@ -485,17 +518,50 @@ PropertyBox::updatePropertyEditor(PropertyContainer::PropertyName name,
     {
         NotifyingComboBox *cb;
 
-        if (!(cb = qobject_cast<NotifyingComboBox *>(existing))) {
+        // Check for a normal NotifyingComboBox. Be careful because
+        // ColourComboBox and ColourMapComboBox both inherit from it,
+        // but we don't want to use either of those
+        if (!(qobject_cast<ColourComboBox *>(existing)) &&
+            !(qobject_cast<ColourMapComboBox *>(existing)) &&
+            (cb = qobject_cast<NotifyingComboBox *>(existing))) {
+#ifdef DEBUG_PROPERTY_BOX 
+            SVDEBUG << "PropertyBox: we already have a combobox" << endl;
+#endif
+        } else {
 #ifdef DEBUG_PROPERTY_BOX 
             SVDEBUG << "PropertyBox: creating new combobox" << endl;
 #endif
             cb = new NotifyingComboBox();
             cb->setObjectName(name);
             cb->setDuplicatesEnabled(false);
+            
+            connect(cb, SIGNAL(activated(int)),
+                    this, SLOT(propertyControllerChanged(int)));
+            connect(cb, SIGNAL(mouseEntered()),
+                    this, SLOT(mouseEnteredWidget()));
+            connect(cb, SIGNAL(mouseLeft()),
+                    this, SLOT(mouseLeftWidget()));
+
+            cb->setToolTip(propertyLabel);
+
+            cb->setContextMenuPolicy(Qt::CustomContextMenu);
+            connect(cb, SIGNAL(customContextMenuRequested(const QPoint &)),
+                    this, SLOT(contextMenuRequested(const QPoint &)));
+
+            if (existing) {
+                groupLayout->replaceWidget(existing, cb);
+                delete existing;
+            } else {
+                groupLayout->addWidget(cb, 0, groupLayout->columnCount());
+            }
+
+            m_propertyControllers[name] = cb;
         }
 
         if (!have || rangeChanged) {
-
+#ifdef DEBUG_PROPERTY_BOX 
+            SVDEBUG << "PropertyBox: new property or range changed, respecifying" << endl;
+#endif
             cb->blockSignals(true);
             cb->clear();
             cb->setEditable(false);
@@ -526,22 +592,6 @@ PropertyBox::updatePropertyEditor(PropertyContainer::PropertyName name,
             }
         }
 
-        if (!have) {
-            connect(cb, SIGNAL(activated(int)),
-                    this, SLOT(propertyControllerChanged(int)));
-            connect(cb, SIGNAL(mouseEntered()),
-                    this, SLOT(mouseEnteredWidget()));
-            connect(cb, SIGNAL(mouseLeft()),
-                    this, SLOT(mouseLeftWidget()));
-
-            cb->setToolTip(propertyLabel);
-            groupLayout->addWidget(cb, 0, groupLayout->columnCount());
-            m_propertyControllers[name] = cb;
-        } else if (existing != cb) {
-            groupLayout->replaceWidget(existing, cb);
-            delete existing;
-        }
-
         cb->blockSignals(true);
         if (type == PropertyContainer::ValueProperty) {
             if (cb->currentIndex() != value) {
@@ -564,6 +614,9 @@ PropertyBox::updatePropertyEditor(PropertyContainer::PropertyName name,
     }
 
     case PropertyContainer::InvalidProperty:
+#ifdef DEBUG_PROPERTY_BOX 
+        SVDEBUG << "PropertyBox: invalid property" << endl;
+#endif
     default:
         break;
     }
@@ -595,6 +648,10 @@ PropertyBox::propertyContainerPropertyRangeChanged(PropertyContainer *)
 {
     blockSignals(true);
 
+#ifdef DEBUG_PROPERTY_BOX
+    SVDEBUG << "PropertyBox::propertyContainerPropertyRangeChanged called" << endl;
+#endif
+    
     PropertyContainer::PropertyList properties = m_container->getProperties();
     for (size_t i = 0; i < properties.size(); ++i) {
         updatePropertyEditor(properties[i], true);
@@ -666,6 +723,62 @@ PropertyBox::propertyControllerChanged(int value)
     updateContextHelp(obj);
 }
 
+void
+PropertyBox::contextMenuRequested(const QPoint &pos)
+{
+    QObject *obj = sender();
+    QString name = obj->objectName();
+    
+    QString label = m_container->getPropertyLabel(name);
+    int min = 0, max = 0, value = 0, deflt = 0;
+    value = m_container->getPropertyRangeAndValue(name, &min, &max, &deflt);
+
+    delete m_lastContextMenu;
+    QMenu *m = new QMenu;
+
+    m_lastContextMenu = m;
+    m_contextMenuOn = obj;
+
+    if (qobject_cast<QAbstractButton *>(obj)) {
+        if (value > 0) {
+            MenuTitle::addTitle(m, tr("%1: On").arg(label));
+        } else {
+            MenuTitle::addTitle(m, tr("%1: Off").arg(label));
+        }
+        m->addAction(tr("&Reset to Default"), this,
+                     SLOT(propertyControllerResetRequested()));
+
+    } else if (auto cb = qobject_cast<QComboBox *>(obj)) {
+        MenuTitle::addTitle(m, tr("%1: %2").arg(label).arg(cb->itemText(value)));
+        m->addAction(tr("&Reset to Default"), this,
+                     SLOT(propertyControllerResetRequested()));
+
+    } else {
+        // AudioDial has its own context menu, we don't handle it here
+        return;
+    }
+        
+    m->popup(qobject_cast<QWidget *>(sender())->mapToGlobal(pos));
+}
+
+void
+PropertyBox::propertyControllerResetRequested()
+{
+    if (!m_contextMenuOn) return;
+    
+    QString name = m_contextMenuOn->objectName();
+    
+    QString label = m_container->getPropertyLabel(name);
+    int min = 0, max = 0, deflt = 0;
+    (void)m_container->getPropertyRangeAndValue(name, &min, &max, &deflt);
+    
+    if (auto button = qobject_cast<QAbstractButton *>(m_contextMenuOn)) {
+        button->setChecked(deflt > 0);
+    } else if (auto cb = qobject_cast<QComboBox *>(m_contextMenuOn)) {
+        cb->setCurrentIndex(deflt);
+    }
+}
+
 void
 PropertyBox::playAudibleChanged(bool audible)
 {
